<?php
/* $Id: polish-windows-1250.inc.php 10478 2007-07-09 19:41:38Z lem9 $ */

$charset = 'windows-1250';
$text_dir = 'ltr';
$number_thousands_separator = '';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('bajtw', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Nie', 'Pon', 'Wto', 'ro', 'Czw', 'Pi', 'Sob');
$month = array('Sty', 'Lut', 'Mar', 'Kwi', 'Maj', 'Cze', 'Lip', 'Sie', 'Wrz', 'Pa', 'Lis', 'Gru');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y, %H:%M';
$timespanfmt = '%s dni, %s godzin, %s minut i %s sekund';

$strAbortedClients = 'Przerwane';
$strAccessDenied = 'Brak dostpu';
$strAccessDeniedCreateConfig = 'Prawdopodobnie powodem jest brak utworzonego pliku konfiguracyjnego. Do jego stworzenia mona uy %1$sskryptu instalacyjnego%2$s.';
$strAccessDeniedExplanation = 'phpMyAdmin prbowa poczy si z serwerem MySQL, a serwer odrzuci poczenie. Powiniene sprawdzi nazw hosta, nazw uytkownika i haso w pliku config.inc.php i upewni si, e odpowiadaj one informacjom danym przez administratora serwera MySQL.';
$strAction = 'Dziaanie';
$strAddAutoIncrement = 'Dodaj wartoci AUTO_INCREMENT';
$strAddClause = 'Dodaj %s';
$strAddConstraints = 'Dodaj ograniczenia';
$strAddDeleteColumn = 'Dodaj/usu pola';
$strAddDeleteRow = 'Dodaj/usu wiersz kryteriw';
$strAddFields = 'Dodaj %s pl';
$strAddHeaderComment = 'Dodaj do nagwka wasny komentarz (\\n oddziela linie)';
$strAddIntoComments = 'Dodaj w komentarzach:';
$strAddNewField = 'Dodaj nowego pole';
$strAddPrivilegesOnDb = 'Dodaj uprawnienia dla nastpujcej bazy danych';
$strAddPrivilegesOnTbl = 'Dodaj uprawnienia dla nastpujcej tabeli';
$strAddSearchConditions = 'Dodaj warunki przeszukiwania (warunek dla "where"):';
$strAddToIndex = 'Dodaj &nbsp;%s&nbsp;kolumn do indeksu ';
$strAddUser = 'Dodaj nowego uytkownika';
$strAddUserMessage = 'Nowy uytkownik zosta dodany.';
$strAdministration = 'Administracja';
$strAffectedRows = 'Zmodyfikowanych rekordw:';
$strAfterInsertBack = 'Wr';
$strAfterInsertNewInsert = 'Dodaj nowy rekord';
$strAfterInsertNext = 'Edytuj nastpny rekord';
$strAfterInsertSame = 'Powrt do tej strony';
$strAfter = 'Po %s';
$strAllowInterrupt = 'Zezwl na przerwanie importu w przypadku, gdy skrypt wykryje zbliajcy si koniec limitu czasu. Moe to by dobry sposb importu duych plikw, jednake moe on popsu transakcje.';
$strAllTableSameWidth = 'wywietli wszystkie tabele z tak sam szerokoci?';
$strAll = 'Wszystko';
$strAlterOrderBy = 'Sortowanie tabeli wg';
$strAnalyzeTable = 'Analizuj tabel';
$strAnd = 'oraz';
$strAndThen = 'a nastpnie';
$strAnIndex = 'Do %s dodany zosta indeks';
$strAny = 'Dowolny';
$strAnyHost = 'Dowolny host';
$strAnyUser = 'Dowolny uytkownik';
$strApproximateCount = 'By moe w przyblieniu. Zobacz FAQ 3.11';
$strAPrimaryKey = 'Do %s dodany zosta klucz podstawowy';
$strArabic = 'Arabski';
$strArmenian = 'Ormiaski';
$strAscending = 'Rosnco';
$strAtBeginningOfTable = 'Na pocztku tabeli';
$strAtEndOfTable = 'Na kocu tabeli';
$strAttr = 'Atrybuty';
$strAutomaticLayout = 'Ukad automatyczny';

$strBack = 'Powrt';
$strBaltic = 'Batycki';
$strBeginCut = 'TNIJ STD';
$strBeginRaw = 'SUROWE DANE STD';
$strBinary = ' Binarne ';
$strBinaryDoNotEdit = ' Binarne - nie do edycji ';
$strBinaryLog = 'Dziennik binarny';
$strBinLogEventType = 'Typ zdarzenia';
$strBinLogInfo = 'Informacje';
$strBinLogName = 'Nazwa dziennika';
$strBinLogOriginalPosition = 'Oryginalna pozycja';
$strBinLogPosition = 'Pozycja';
$strBinLogServerId = 'ID serwera';
$strBookmarkAllUsers = 'Pozwl na dostp wszystkim uytkownikom';
$strBookmarkCreated = 'Zapytanie %s zostao zapamitane';
$strBookmarkDeleted = 'Zapamitane zapytanie SQL zostao usunite.';
$strBookmarkLabel = 'Nazwa';
$strBookmarkQuery = 'Zapamitane zapytanie SQL';
$strBookmarkReplace = 'Zamie istniejce zapamitane zapytanie o tej samej nazwie';
$strBookmarkThis = 'Pamitaj zapytanie SQL';
$strBookmarkView = 'Tylko poka';
$strBrowseDistinctValues = 'Przegldaj rne wartoci';
$strBrowseForeignValues = 'Przegldaj zewntrzne wartoci';
$strBrowse = 'Przegldaj';
$strBufferPoolActivity = 'Aktywno rezerw buforowych';
$strBufferPool = 'Rezerwy buforowe';
$strBufferPoolUsage = 'Uycie rezerw buforowych';
$strBufferReadMisses = 'Chybienia odczytu';
$strBufferReadMissesInPercent = 'Chybienia odczytu w %';
$strBufferWriteWaitsInPercent = 'Oczekiwania zapisu w %';
$strBufferWriteWaits = 'Oczekiwania na zapis';
$strBulgarian = 'Bugarski';
$strBusyPages = 'Strony uywane';
$strBzError = 'phpMyAdminowi nie udao si skompresowa zrzutu z powodu zepsutego rozszerzenia Bz2 w tej wersji PHP. Jest bardzo zalecane by ustawi dyrektyw <code>$cfg[\'BZipDump\']</code> w pliku konfiguracyjnym phpMyAdmina na <code>FALSE</code>. Jeli chcesz uy funkcji kompresji Bz2, PHP powinien zosta zaktualizowany do najnowszej wersji. Szczegy mona zobaczy w raporcie na temat bdw PHP %s.';
$strBzip = '".bz2"';

$strCalendar = 'Kalendarz';
$strCanNotLoadExportPlugins = 'Nie udao si zaadowa moduw eksportu, prosz sprawdzi instalacj!';
$strCanNotLoadImportPlugins = 'Nie udao si zaadowa moduw importu, prosz sprawdzi instalacj!';
$strCannotLogin = 'Nie udao si zalogowa na serwer MySQL';
$strCantLoad = 'nie udao si zaadowa moduu %s,<br />prosz sprawdzi konfiguracj PHP';
$strCantLoadRecodeIconv = 'Nie udao si zaadowa rozszerze iconv lub recode, ktre s niezbdne do konwersji kodowania znakw, skonfiguruj PHP tak, by mg uywa tych rozszerze albo zablokuj konwersj kodowania znakw w phpMyAdminie.';
$strCantRenameIdxToPrimary = 'Nie mona zmieni nazwy indeksu na PRIMARY!';
$strCantUseRecodeIconv = 'Nie udao si uy ani funkcji iconv, ani libiconv, mimo e rozszerzenia zgaszaj si jako zaadowane. Prosz sprawdzi swoj konfiguracj PHP.';
$strCardinality = 'Moc';
$strCaseInsensitive = 'bez rozrniania wielkoci liter';
$strCaseSensitive = 'z rozrnianiem wielkoci liter';
$strCentralEuropean = 'rodkowoeuropejski';
$strChangeCopyModeCopy = '... pozostaw starego.';
$strChangeCopyModeDeleteAndReload = ' ... usu starego z tabel uytkownikw, a nastpnie przeaduj uprawnienia.';
$strChangeCopyModeJustDelete = ' ... usu starego z tabel uytkownikw.';
$strChangeCopyModeRevoke = ' ... odbierz wszystkie aktywne uprawnienia staremu, a nastpnie go usu.';
$strChangeCopyMode = 'Utwrz nowego uytkownika z takimi samymi uprawnieniami i ...';
$strChangeCopyUser = 'Zmie dane uytkownika / Skopiuj uytkownika';
$strChangeDisplay = 'Wybierz wywietlane pole';
$strChangePassword = 'Zmie haso';
$strChange = 'Zmie';
$strCharsetOfFile = 'Zestaw znakw dla pliku:';
$strCharsetsAndCollations = 'Zestawy znakw i metody porwnywania napisw';
$strCharsets = 'Zestawy znakw';
$strCharset = 'Zestaw znakw';
$strCheckAll = 'Zaznacz wszystkie';
$strCheckOverhead = 'Zaznacz nieoptymalne';
$strCheckPrivsLong = 'Sprawd uprawnienia bazy danych &quot;%s&quot;.';
$strCheckPrivs = 'Sprawd uprawnienia';
$strCheckTable = 'Sprawd tabel';
$strChoosePage = 'Prosz wybra stron do edycji';
$strColComFeat = 'Wywietl komentarze dla kolumn';
$strCollation = 'Metoda porwnywania napisw';
$strColumnNames = 'Nazwy kolumn';
$strColumnPrivileges = 'Uprawnienia specyficzne dla kolumn';
$strCommand = 'Polecenie';
$strCommentsForTable = 'KOMENTARZE TABELI';
$strComments = 'Komentarze';
$strCompatibleHashing = 'Kompatybilny z MySQL-em&nbsp;4.0';
$strCompleteInserts = 'Pene dodania';
$strCompression = 'Typ kompresji';
$strCompressionWillBeDetected = 'Rodzaj kompresji importowanych plikw zostanie automatycznie rozpoznany jako jeden z: %s';
$strConfigDefaultFileError = 'Nie udao si zaadowa domylnej konfiguracji z pliku: "%1$s"';
$strConfigFileError = 'phpMyAdmin nie zdoa odczyta Twojego pliku konfiguracji!<br />Moe si to zdarzy, jeli PHP znajdzie w nim bd skadniowy lub nie moe znale tego pliku.<br />Prosz wywoa bezporednio plik konfiguracyjny uywajc poniszego linku i odczyta otrzymane komunikat(y) o bdach. W wikszoci przypadkw brakuje gdzie cudzysowu lub rednika.<br />Jeeli otrzymasz pust stron, wszystko jest w porzdku.';
$strConfigureTableCoord = 'Prosz skonfigurowa wsprzdnie dla tabeli %s';
$strConnectionError = 'Nie udao si nawiza poczenia: bdne ustawienia.';
$strConnections = 'Poczenia';
$strConstraintsForDumped = 'Ograniczenia dla zrzutw tabel';
$strConstraintsForTable = 'Ograniczenia dla tabeli';
$strCookiesRequired = 'Odtd musi by wczona obsuga ciasteczek [<i>cookies</i>].';
$strCopyDatabaseOK = 'Baza danych %s zostaa skopiowana do %s';
$strCopy = 'Kopiuj';
$strCopyTableOK = 'Tabela %s zostaa skopiowana do %s.';
$strCopyTableSameNames = 'Nie mona skopiowa tabeli do niej samej!';
$strCopyTable = 'Skopiuj tabel do (bazadanych<b>.</b>tabela):';
$strCouldNotKill = 'phpMyAdminowi nie udao si unicestwi wtku %s. Prawdopodobnie zosta on ju zamknity.';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE przed skopiowaniem';
$strCreateIndexTopic = 'Utwrz nowy indeksu';
$strCreateIndex = 'Utwrz indeks dla %s kolumn';
$strCreateNewDatabase = 'Utwrz now baz danych';
$strCreateNewTable = 'Utwrz now tabel w bazie danych %s';
$strCreatePage = 'Utwrz now stron';
$strCreatePdfFeat = 'Tworzenie PDF-w';
$strCreateUserDatabase = 'Baza danych dla uytkownika';
$strCreateUserDatabaseName = 'Utwrz baz danych z tak sam nazw i przyznaj wszystkie uprawnienia';
$strCreateUserDatabaseNone = 'Brak';
$strCreateUserDatabaseWildcard = 'Przyznaj wszystkie uprawienia do baz danych o nazwach pasujcych do maski (nazwauytkownika_%)';
$strCreate = 'Utwrz';
$strCreationDates = 'Daty utworzenia/aktualizacji/sprawdzenia';
$strCriteria = 'Kryteria';
$strCroatian = 'Chorwacki';
$strCSV = 'CSV';
$strCyrillic = 'Cyrylica';
$strCzech = 'Czeski';
$strCzechSlovak = 'Czesko-sowacki';

$strDanish = 'Duski';
$strDatabase = 'Baza danych';
$strDatabaseEmpty = 'Nazwa bazy danych jest pusta!';
$strDatabaseExportOptions = 'Opcje eksportu bazy danych';
$strDatabaseHasBeenDropped = 'Baza danych %s zostaa usunita.';
$strDatabases = 'Bazy danych';
$strDatabasesDropped = '%s baz danych zostao pomylnie usunitych.';
$strDatabasesStatsDisable = 'Wycz statystyki';
$strDatabasesStatsEnable = 'Wcz statystyki';
$strDatabasesStatsHeavyTraffic = 'Uwaga: Wczenie statystyk baz danych moe spowodowa duy ruch pomidzy serwerem WWW a serwerem MySQL.';
$strDatabasesStats = 'Statystyki baz danych';
$strData = 'Dane';
$strDataDict = 'Sownik danych';
$strDataOnly = 'Tylko dane';
$strDataPages = 'Strony zawierajce dane';
$strDBComment = 'Komentarz bazy danych: ';
$strDBCopy = 'Kopiuj baz danych do';
$strDbPrivileges = 'Uprawnienia specyficzne dla baz danych';
$strDBRename = 'Zmie nazw bazy danych na';
$strDbSpecific = 'specyficzne dla bazy danych';
$strDefault = 'Domylnie';
$strDefaultEngine = '%s to domylny mechanizm skadowania tego serwera MySQL.';
$strDefaultValueHelp = 'Dla wartoci domylnych, prosz wprowadzi po prostu pojedyncz warto, bez cytowania odwrotnym ukonikiem czy ujmowania w cudzysowy, uywajc takiego formatu: a';
$strDefragment = 'Tablica defragmentacji';
$strDelayedInserts = 'Uyj opnionych doda';
$strDeleteAndFlushDescr = 'Jest to najzgrabniejszy sposb, ale przeadowanie uprawnie moe potrwa jaki czas.';
$strDeleteAndFlush = 'Usu uytkownikw, a nastpnie przeaduj uprawnienia.';
$strDeleted = 'Rekord zosta skasowany';
$strDeletedRows = 'Skasowane rekordy:';
$strDeleteNoUsersSelected = 'aden uytkownik ze zosta zaznaczony do skasowania!';
$strDelete = 'Usu';
$strDeleting = 'Usuwanie %s';
$strDelimiter = 'Separator';
$strDelOld = 'Aktualna strona ma powizania z tabel, ktra ju nie istnieje. Czy chcesz usun te powizania?';
$strDescending = 'Malejco';
$strDescription = 'Opis';
$strDictionary = 'sownik';
$strDirtyPages = 'Strony brudne';
$strDisabled = 'wyczone';
$strDisableForeignChecks = 'Wycz sprawdzanie kluczy zewntrznych';
$strDisplayFeat = 'Funkcje wywietlania';
$strDisplayOrder = 'Kolejno wywietlania:';
$strDisplayPDF = 'Wywietl schemat PDF';
$strDoAQuery = 'Wykonaj "zapytanie przez przykad" (znak globalny: "%")';
$strDocu = 'Dokumentacja';
$strDoYouReally = 'Czy na pewno wykona ';
$strDropDatabaseStrongWarning = 'Masz zamiar ZNISZCZY ca baz danych!';
$strDropUsersDb = 'Usu bazy danych o takich samych nazwach jak uytkownicy.';
$strDrop = 'Usu';
$strDumpingData = 'Zrzut danych tabeli';
$strDumpSaved = 'Zrzut zosta zapisany do pliku %s.';
$strDumpXRows = 'Zrzu %s rekordw zaczynajc od rekordu %s.';
$strDynamic = 'zmienny';

$strEdit = 'Edytuj';
$strEditPDFPages = 'Edytuj strony PDF';
$strEditPrivileges = 'Edytuj uprawnienia';
$strEffective = 'Efektywne';
$strEmptyResultSet = 'MySQL zwrci pusty wynik (zero rekordw).';
$strEmpty = 'Wyczy';
$strEnabled = 'wczone';
$strEncloseInTransaction = 'Obejmij eksport transakcj';
$strEndCut = 'TNIJ DOTD';
$strEnd = 'Koniec';
$strEndRaw = 'SUROWE DANE DOTD';
$strEngineAvailable = '%s jest dostpny na tym serwerze MySQL.';
$strEngineDisabled = 'Mechanizm %s zosta wyczony w tym serwerze MySQL.';
$strEngines = 'Mechanizmy';
$strEngineUnsupported = 'Ten serwer MySQL nie obsuguje mechanizmu skadowania %s.';
$strEnglish = 'Angielski';
$strEnglishPrivileges = ' Uwaga: Uprawnienia MySQL s oznaczone w jzyku angielskim ';
$strError = 'Bd';
$strErrorInZipFile = 'Bd w archiwum ZIP:';
$strErrorRenamingTable = 'Bd podczas zmiany nazwy tabeli z %1$s na %2$s';
$strEscapeWildcards = 'Aby uy symboli wieloznacznych _ i % w znaczeniu dosownym, naley je poprzedzi znakiem \ ';
$strEsperanto = 'Esperanto';
$strEstonian = 'Estoski';
$strExcelEdition = 'Wydanie Excela';
$strExecuteBookmarked = 'Wykonaj zapamitanego zapytania';
$strExplain = 'Wyjanij SQL';
$strExport = 'Eksport';
$strExportMustBeFile = 'Wybrany typ eksportu musi by zapisany do pliku';
$strExtendedInserts = 'Rozszerzone dodania';
$strExtra = 'Dodatkowo';

$strFailedAttempts = 'Nieudane prby';
$strFieldHasBeenDropped = 'Pole %s zostao usunite';
$strField = 'Pole';
$strFieldsEnclosedBy = 'Pola zawarte w';
$strFieldsEscapedBy = 'Pola poprzedzone przez';
$strFields = 'Pola';
$strFieldsTerminatedBy = 'Pola oddzielane przez';
$strFileAlreadyExists = 'Plik %s ju istnieje na serwerze, zmie nazw pliku lub zaznacz opcj nadpisywania plikw.';
$strFileCouldNotBeRead = 'Nie mona odczyta pliku';
$strFileNameTemplateDescriptionDatabase = 'nazwa bazy danych';
$strFileNameTemplateDescription = 'Interpretacja tej wartoci naley do funkcji %1$sstrftime%2$s i mona uy jej napisw formatujcych. Dodatkowo zostan zastosowane nastpujce przeksztacenia: %3$s. Pozostay tekst bdzie niezmieniony.';
$strFileNameTemplateDescriptionServer = 'nazwa serwera';
$strFileNameTemplateDescriptionTable = 'nazwa tabeli';
$strFileNameTemplateRemember = 'pamitaj szablon';
$strFileNameTemplate = 'Szablon nazwy';
$strFileToImport = 'Plik do importu';
$strFixed = 'stay';
$strFlushPrivilegesNote = 'Uwaga: phpMyAdmin pobiera uprawnienia uytkownikw wprost z tabeli uprawnie MySQL-a. Zawarto tej tabeli, jeli zostay w niej dokonane rczne zmiany, moe si rni od uprawnie jakich faktycznie uywa serwer. W takim przypadku powiniene przed dalsz prac %sprzeadowa uprawnienia%s.';
$strFlushQueryCache = 'Oprnij bufor podrczny zapyta';
$strFlushTable = 'Przeaduj tabel ("FLUSH")';
$strFlushTables = 'Przeaduj (zamknij) wszystkie tabele';
$strFontSize = 'Rozmiar pisma';
$strFormat = 'Format';
$strFormEmpty = 'Brakujca warto w formularzu!';
$strFreePages = 'Strony puste';
$strFullText = 'Peny tekst';
$strFunction = 'Funkcja';
$strFunctions = 'Funkcje';

$strGenBy = 'Wygenerowany przez';
$strGeneralRelationFeat = 'Oglne funkcje relacyjne';
$strGenerate = 'Generuj';
$strGeneratePassword = 'Generuj haso';
$strGenTime = 'Czas wygenerowania';
$strGeorgian = 'Gruziski';
$strGerman = 'Niemiecki';
$strGlobal = 'globalnie';
$strGlobalPrivileges = 'Globalne uprawnienia';
$strGlobalValue = 'Warto globalna';
$strGo = 'Wykonaj';
$strGrantOption = 'Nadawanie';
$strGreek = 'Grecki';
$strGzip = '".gz"';

$strHandler = 'Obsuga';
$strHasBeenAltered = 'zostao zamienione.';
$strHasBeenCreated = 'zostao utworzone.';
$strHaveToShow = 'Naley wybra przynajmniej jedn kolumn do wywietlenia';
$strHebrew = 'Hebrajski';
$strHomepageOfficial = 'Oficjalna strona phpMyAdmina';
$strHome = 'Wejcie';
$strHostEmpty = 'Brak nazwy hosta!';
$strHost = 'Host';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHungarian = 'Wgierski';

$strIcelandic = 'Islandzki';
$strId = 'ID';
$strIdxFulltext = 'Peny tekst';
$strIgnoreDuplicates = 'Ignoruj zdublowane rekordy';
$strIgnore = 'Ignoruj';
$strIgnoreInserts = 'Uyj ignorowanych doda';
$strImportFiles = 'Import plikw';
$strImportFormat = 'Format importowanych plikw';
$strImport = 'Import';
$strImportSuccessfullyFinished = 'Import zakoczony sukcesem, wykonano %d zapyta.';
$strIndexes = 'Indeksy';
$strIndexHasBeenDropped = 'Klucz %s zosta usunity';
$strIndex = 'Indeks';
$strIndexName = 'Nazwa indeksu :';
$strIndexType = 'Rodzaj indeksu :';
$strIndexWarningTable = 'Problemy z indeksami tabeli `%s`';
$strInnoDBAutoextendIncrementDesc = 'Rozmiar o jaki automatycznie powikszy si tabela, kiedy zostanie zapeniona.';
$strInnoDBAutoextendIncrement = 'Przyrost autoextend';
$strInnoDBBufferPoolSizeDesc = 'Ilo pamici, ktrej InnoDB uywa do buforowania danych i indeksw swoich tabel.';
$strInnoDBBufferPoolSize = 'Rozmiar rezerw buforowych';
$strInnoDBDataFilePath = 'Pliki danych';
$strInnoDBDataHomeDirDesc = 'Wsplna cz cieki do wszystkich plikw danych InnoDB.';
$strInnoDBDataHomeDir = 'Katalog domowy danych';
$strInnoDBPages = 'stron';
$strInnodbStat = 'Status InnoDB';
$strInsecureMySQL = 'Twj plik konfiguracyjny zawiera ustawienia (konto roota bez hasa), ktre odpowiadaj domylnemu uprzywilejowanemu kontu MySQL. Twj serwer MySQL dziaa z takim ustawieniem, jest otwarty dla wamywaczy. Ta luka w bezpieczestwie naprawd powinna zosta naprawiona.';
$strInsertAsNewRow = 'Dodaj jako nowy rekord';
$strInsert = 'Dodaj';
$strInsertedRowId = 'Identyfikator dodanego rekordu:';
$strInsertedRows = 'Dodane rekordy:';
$strInternalNotNecessary = '* Wewntrzna relacja nie jest konieczna gdy istnieje rwnie w InnoDB.';
$strInternalRelations = 'Wewntrzne relacje';
$strInUse = 'w uyciu';
$strInvalidAuthMethod = 'W konfiguracji ustawiono bdn metod uwierzytelniania:';
$strInvalidColumnCount = 'Liczba kolumn musi by wiksza ni zero.';
$strInvalidColumn = 'Podano bdn kolumn (%s)!';
$strInvalidCSVFieldCount = 'Niewaciwa liczba pl w linii %d danych wejciowych CSV.';
$strInvalidCSVFormat = 'Niewaciwy format w linii %d danych wejciowych CSV.';
$strInvalidCSVParameter = 'Niewaciwy parametr importu CSV: %s';
$strInvalidDatabase = 'Niewaciwa baza danych';
$strInvalidFieldAddCount = 'Naley doda przynajmniej jedno pole.';
$strInvalidFieldCount = 'Tabela musi mie przynajmniej jedno pole.';
$strInvalidLDIImport = 'Ten modu nie obsuguje skompresowanych importw!';
$strInvalidRowNumber = '%d nie jest prawidowym numerem rekordu.';
$strInvalidServerHostname = 'Niewaciwa nazwa hosta serwera %1$s. Prosz przyjrze si konfiguracji.';
$strInvalidServerIndex = 'Niewaciwy numer serwera: "%s"';
$strInvalidTableName = 'Niewaciwa nazwa tabeli';

$strJapanese = 'Japoski';
$strJoins = 'Zczenia';
$strJumpToDB = 'Skok do bazy danych &quot;%s&quot;.';
$strJustDeleteDescr = 'Nim uprawnienia zostan przeadowane, &quot;usunici&quot; uytkownicy nadal bd mieli dotychczasowy dostp do serwera.';
$strJustDelete = 'Po prostu usu uytkownikw z tabeli uprawnie.';

$strKeepPass = 'Nie zmieniaj hasa';
$strKeyCache = 'Bufor podrczny indeksw';
$strKeyname = 'Nazwa klucza';
$strKill = 'Unicestwij';
$strKorean = 'Koreaski';

$strLandscape = 'Orientacja pozioma';
$strLanguage = 'Jzyk';
$strLanguageUnknown = 'Nieznany jzyk: %1$s.';
$strLatchedPages = 'Stron zatrzanitych';
$strLatexCaption = 'Nagwek tabeli';
$strLatexContent = 'Zawarto tabeli __TABLE__';
$strLatexContinuedCaption = 'Kontynuacja nagwka tabeli';
$strLatexContinued = '(kontynuacja)';
$strLatexIncludeCaption = 'Zacz nagwek tabeli';
$strLatexLabel = 'Etykieta klucza';
$strLaTeX = 'LaTeX';
$strLatexStructure = 'Struktura tabeli __TABLE__';
$strLatvian = 'otewski';
$strLDI = 'CSV przy uyciu LOAD DATA';
$strLDILocal = 'Uyj sowa kluczowego LOCAL';
$strLengthSet = 'Dugo/Wartoci*';
$strLimitNumRows = 'rekordw na stronie';
$strLinesTerminatedBy = 'Linie zakoczone przez';
$strLinkNotFound = 'cze nie znalezione';
$strLinksTo = 'cze';
$strLithuanian = 'Litewski';
$strLocalhost = 'Host lokalny';
$strLocationTextfile = 'Lokalizacja pliku tekstowego';
$strLoginInformation = 'Dane uytkownika';
$strLogin = 'Login';
$strLogout = 'Wyjcie';
$strLogPassword = 'Haso:';
$strLogServer = 'Serwer';
$strLogUsername = 'Uytkownik:';
$strLongOperation = 'Ta operacja moe trwa dugo. Czy mimo to kontynuowa?';

$strMaxConnects = 'Maks. jednoczesnych pocze';
$strMaximalQueryLength = 'Maksymalna dugo utworzonego zapytania';
$strMaximumSize = 'Maksymalny rozmiar: %s%s';
$strMbExtensionMissing = 'Rozszerzenie PHP o nazwie mbstring nie zostao znalezione, a wyglda na to, e uywasz wielobajtowego zestawu znakw. Bez rozszerzenia mbstring phpMyAdmin nie ma moliwoci poprawnego rozbijania napisw, co moe skutkowa niespodziewanymi rezultatami.';
$strMbOverloadWarning = 'Opcja mbstring.func_overload jest wczona w pliku konfiguracyjnym PHP. Jest ona niezgodna z phpMyAdminem i moe powodowa utrat niektrych danych!';
$strMIME_available_mime = 'Dostpne typy MIME';
$strMIME_available_transform = 'Dostpne transformacje';
$strMIME_description = 'Opis';
$strMIME_MIMEtype = 'Typ MIME';
$strMIME_nodescription = 'Transformacja ta nie ma opisu.<br />Prosz zapyta autora, co robi %s.';
$strMIME_transformation_note = 'Aby uzyska list dostpnych opcji transformacji i ich typw MIME, kliknij %sopisy transformacji%s';
$strMIME_transformation_options_note = 'Prosz wprowadzi wartoci dla transformacji w nastpujcym formacie: \'a\', 100, b,\'c\'...<br />Jeeli potrzeba wprowadzi odwrotny ukonik ("\") lub apostrof ("\'"), naley je poprzedzi odwrotnym ukonikiem (np.: \'\\\\xyz\' lub \'a\\\'b\').';
$strMIME_transformation_options = 'Opcje transformacji';
$strMIME_transformation = 'Sposb prezentacji danych';
$strMIMETypesForTable = 'TYPY MIME TABELI';
$strMIME_without = 'Typy MIME pisane czcionk pochylon nie maj oddzielnej funkcji transformacji';
$strModifications = 'Modyfikacje zostay zapamitane';
$strModifyIndexTopic = 'Modyfikacja indeksu';
$strModify = 'Modyfikacja';
$strMoveTableOK = 'Tabela %s zostaa przeniesiona do %s.';
$strMoveTable = 'Przenie tabel do (bazadanych<b>.</b>tabela):';
$strMoveTableSameNames = 'Nie mona przenie tabeli do niej samej!';
$strMultilingual = 'wiele jzykw';
$strMyISAMDataPointerSizeDesc = 'Domylny rozmiar wskanika w bajtach, ktry jest uywany przez CREATE TABLE dla tabel MyISAM, gdy nie okrelono opcji MAX_ROWS.';
$strMyISAMDataPointerSize = 'Rozmiar wskanika danych';
$strMyISAMMaxExtraSortFileSizeDesc = 'Jeeli plik tymczasowy uyty przy szybkim tworzeniu indeksu MyISAM byby wikszy o warto tu okrelon, ni w wypadku zastosowania metody pamici podrcznej kluczy, preferuj t drug metod.';
$strMyISAMMaxExtraSortFileSize = 'Maksymalny rozmiar pliku tymczasowego dla tworzenia indeksu';
$strMyISAMMaxSortFileSizeDesc = 'Maksymalny rozmiar pliku tymczasowego, ktrego moe zosta uyty przy ponownym tworzeniu indeksu MyISAM (podczas operacji REPAIR TABLE, ALTER TABLE lub LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maksymalny rozmiar pliku tymczasowego dla sortowania';
$strMyISAMRecoverOptionsDesc = 'Tryb w ktrym po awarii tabele MyISAM s automatycznie naprawiane; wczany przez opcj startow serwera --myisam-recover.';
$strMyISAMRecoverOptions = 'Tryb automatycznej naprawy';
$strMyISAMRepairThreadsDesc = 'Warto wiksza ni 1 oznacza, e indeksy tabel MyISAM s tworzone wspbienie (kady indeks ma swj wtek) podczas naprawy przez proces sortujcy.';
$strMyISAMRepairThreads = 'Liczba wtkw naprawiajcych';
$strMyISAMSortBufferSizeDesc = 'Bufor, ktry jest alokowany w czasie sortowania indeksw MyISAM podczas operacji REPAIR TABLE albo gdy indeksy s tworzone przez polecenia CREATE INDEX lub ALTER TABLE.';
$strMyISAMSortBufferSize = 'Rozmiar bufora dla sortowania';
$strMySQLCharset = 'System kodowania znakw dla MySQL';
$strMysqlClientVersion = 'Wersja klienta MySQL';
$strMySQLConnectionCollation = 'System porwna dla poczenia MySQL';
$strMySQLSaid = 'MySQL zwrci komunikat: ';
$strMySQLShowProcess = 'Poka procesy';
$strMySQLShowStatus = 'Informacje o stanie serwera MySQL';
$strMySQLShowVars = 'Zmienne systemowe serwera MySQL';

$strName = 'Nazwa';
$strNext = 'Nastpne';
$strNoActivity = 'Brak aktywnoci przez co najmniej %s sekund, prosz zalogowa si jeszcze raz';
$strNoDatabases = 'Brak baz danych';
$strNoDatabasesSelected = 'adna baza danych nie zosta wybrana.';
$strNoDataReceived = 'Nie otrzymano adnych danych do importu. Albo nie zostaa wysana nazwa pliku, albo plik by zbyt duy (maksymalny dopuszczalny rozmiar pliku okrela si w konfiguracji PHP). Zobacz FAQ 1.16.';
$strNoDescription = 'brak opisu';
$strNoDetailsForEngine = 'Brak szczegowych informacji o tym mechanizmie skadowania';
$strNoDropDatabases = 'Polecenie "DROP DATABASE" jest zablokowane.';
$strNoExplain = 'Pomi wyjanienie SQL';
$strNoFilesFoundInZip = 'Archiwum ZIP jest puste!';
$strNoFrames = 'phpMyAdmin jest bardziej przyjazny w przegldarkach <b>obsugujcych ramki</b>';
$strNoIndex = 'Brak zdefiniowanego indeksu!';
$strNoIndexPartsDefined = 'Brak zdefiniowanych czci indeksu!';
$strNoModification = 'Bez zmian';
$strNone = 'Brak';
$strNo = 'Nie';
$strNoOptions = 'Ten format nie ma adnych opcji';
$strNoPassword = 'Brak hasa';
$strNoPermission = 'Serwer WWW nie ma praw do zapisu pliku %s.';
$strNoPhp = 'bez kodu PHP';
$strNoPrivileges = 'Brak uprawnie';
$strNoRights = 'Brak wystarczajcych uprawnie!';
$strNoRowsSelected = 'aden rekord nie zosta zaznaczony';
$strNoSpace = 'Brak miejsca na zapis pliku %s.';
$strNoTablesFound = 'Nie znaleziono tabeli w bazie danych.';
$strNoThemeSupport = 'Brak obsugi motyww graficznych, prosz sprawdzi konfiguracj i/lub motywy graficzne w katalogu %s.';
$strNotNumber = 'To nie jest liczba!';
$strNotOK = 'bd';
$strNotSet = 'Tabela <b>%s</b> nie zostaa znaleziona lub nie jest ustawiona w %s';
$strNoUsersFound = 'Nie znaleziono uytkownika(w).';
$strNoValidateSQL = 'Pomi sprawdzanie poprawnoci SQL';
$strNull = 'Null';
$strNumberOfFields = 'Liczba pl';
$strNumSearchResultsInTable = '%s trafie wewntrz tabeli <i>%s</i>';
$strNumSearchResultsTotal = '<b>W sumie:</b> <i>%s</i> trafie';
$strNumTables = 'Tabele';

$strOK = 'OK';
$strOpenDocumentSpreadsheet = 'arkusz kalkulacyjny w formacie Open Document';
$strOpenDocumentText = 'Tekst w formacie Open Document';
$strOpenNewWindow = 'Otwrz nowe okno phpMyAdmina';
$strOperations = 'Operacje';
$strOperator = 'Operator';
$strOptimizeTable = 'Optymalizuj tabel';
$strOr = 'lub';
$strOverhead = 'Nadmiar';
$strOverwriteExisting = 'Nadpisuj istniejce pliki';

$strPageNumber = 'Numer strony:';
$strPagesToBeFlushed = 'Strony do wymiecenia';
$strPaperSize = 'Rozmiar papieru';
$strPartialImport = 'Import czciowy';
$strPartialText = 'Skrcony tekst';
$strPasswordChanged = 'Haso dla %s zostao pomylnie zmienione.';
$strPasswordEmpty = 'Puste haso!';
$strPassword = 'Haso';
$strPasswordHashing = 'Sposb kodowania hase';
$strPasswordNotSame = 'Hasa nie s identyczne!';
$strPdfDbSchema = 'Schemat bazy danych "%s" - strona %s';
$strPdfInvalidTblName = 'Tabela "%s" nie istnieje!';
$strPdfNoTables = 'Brak tabel';
$strPDF = 'PDF';
$strPDFReportExplanation = '(Generuje raport zawierajcy danej pojedynczej tabeli.)';
$strPDFReportTitle = 'Tytu raportu';
$strPerHour = 'na godzin';
$strPerMinute = 'na minut';
$strPerSecond = 'na sekund';
$strPersian = 'Perski';
$strPhoneBook = 'ksika telefoniczna';
$strPHP40203 = 'Uywasz PHP w wersji 4.2.3, ktra ma powany bd w obsudze napisw wielobajtowych (mbstring). Zobacz raport na temat bdw PHP nr 19404. Nie zaleca si uywania tej wersji PHP z phpMyAdminem.';
$strPhp = 'Utwrz kod PHP';
$strPHPVersion = 'Wersja PHP';
$strPmaDocumentation = 'Dokumentacja phpMyAdmina';
$strPmaUriError = 'Dyrektywa <tt>$cfg[\'PmaAbsoluteUri\']</tt> musi by ustawiona w pliku konfiguracyjnym!';
$strPolish = 'Polski';
$strPortrait = 'Orientacja pionowa';
$strPos1 = 'Pocztek';
$strPrevious = 'Poprzednie';
$strPrimaryKeyHasBeenDropped = 'Klucz podstawowy zosta usunity';
$strPrimaryKeyName = 'Nazw podstawowego klucza musi by... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>musi</b> by nazw <b>jedynie</b> klucza podstawowego!)';
$strPrimary = 'Podstawowy';
$strPrint = 'Drukuj';
$strPrintViewFull = 'Widok do druku (z penymi tekstami)';
$strPrintView = 'Widok do druku';
$strPrivDescAllPrivileges = 'Wszystkie uprawnienia, oprcz GRANT.';
$strPrivDescAlter = 'Pozwl zmienia struktur istniejcych tabel.';
$strPrivDescAlterRoutine = 'Pozwl modyfikowa i usuwa procedury skadowane.';
$strPrivDescCreateDb = 'Pozwl tworzy nowe bazy danych i tabele.';
$strPrivDescCreateRoutine = 'Pozwl tworzy procedury skadowane.';
$strPrivDescCreateTbl = 'Pozwl tworzy nowe tabele.';
$strPrivDescCreateTmpTable = 'Pozwala tworzy tabele tymczasowe.';
$strPrivDescCreateUser = 'Pozwl tworzy, usuwa i zmienia nazwy kont uytkownikw.';
$strPrivDescCreateView = 'Pozwl tworzy perspektywy.';
$strPrivDescDelete = 'Pozwl usuwa dane.';
$strPrivDescDropDb = 'Pozwl usuwa bazy danych i tabele.';
$strPrivDescDropTbl = 'Pozwl usuwa tabele.';
$strPrivDescExecute5 = 'Pozwl wykonywa procedury skadowane.';
$strPrivDescExecute = 'Pozwl uruchamia zapamitane procedury; Nie ma adnych skutkw w tej wersji MySQL.';
$strPrivDescFile = 'Pozwl importowa i eksportowa dane z/do plikw.';
$strPrivDescGrant = 'Pozwl dodawa uytkownikw i nadawa uprawnienia bez przeadowywania tabeli uprawnie.';
$strPrivDescIndex = 'Pozwl tworzy i usuwa indeksy.';
$strPrivDescInsert = 'Pozwl dodawa i zamienia dane.';
$strPrivDescLockTables = 'Pozwl blokowa tabele dla aktualnego wtku.';
$strPrivDescMaxConnections = 'Ogranicz liczb nowych pocze, ktre moe otworzy uytkownik w cigu godziny.';
$strPrivDescMaxQuestions = 'Ogranicz liczb zapyta, ktre moe wysa uytkownik w cigu godziny.';
$strPrivDescMaxUpdates = 'Ogranicz liczb polece zmieniajcych jakkolwiek tabel lub baz danych, ktre moe wykona uytkownik w cigu godziny.';
$strPrivDescMaxUserConnections = 'Ogranicz liczb jednoczesnych pocze, ktre moe uytkownik.';
$strPrivDescProcess3 = 'Pozwl unicestwia procesy innych uytkownikw.';
$strPrivDescProcess4 = 'Pozwl zobaczy pen list zapyta na licie procesw.';
$strPrivDescReferences = 'Nie ma adnych skutkw w tej wersji MySQL.';
$strPrivDescReload = 'Pozwl przeadowywa ustawienia serwera i oprnia pami podrczn serwera.';
$strPrivDescReplClient = 'Nadaj uytkownikowi prawo, by zapyta gdzie s serwery podrzdne / nadrzdne.';
$strPrivDescReplSlave = 'Potrzebne dla replikacji serwera podrzdnego.';
$strPrivDescSelect = 'Pozwl czyta dane.';
$strPrivDescShowDb = 'Daj dostp do penej listy baz danych.';
$strPrivDescShowView = 'Pozwl wykonywa zapytania SHOW CREATE VIEW.';
$strPrivDescShutdown = 'Pozwl zamkn serwer.';
$strPrivDescSuper = 'Pozwl na poczenie, nawet jeli osignita zostaa maksymalna ilo pocze; Wymagane dla wikszo operacji administracyjnych, takich jak ustawianie zmiennych globalnych czy unicestwianie wtkw innych uytkownikw.';
$strPrivDescUpdate = 'Pozwl zmienia dane.';
$strPrivDescUsage = 'Brak uprawnie.';
$strPrivilegesReloaded = 'Uprawnienia zostay pomylnie przeadowane.';
$strPrivileges = 'Uprawnienia';
$strProcedures = 'Procedury';
$strProcesses = 'Procesy';
$strProcesslist = 'Lista procesw';
$strProtocolVersion = 'Wersja protokou';
$strPutColNames = 'Umie nazwy pl w pierwszym rekordzie';

$strQBEDel = 'Usu';
$strQBEIns = 'Dodaj';
$strQBE = 'Zapytanie przez przykad';
$strQueryCache = 'Pami podrczna zapyta';
$strQueryFrame = 'Okienko zapytania';
$strQueryOnDb = 'Zapytanie SQL dla bazy danych <b>%s</b>:';
$strQueryResultsOperations = 'Operacja na wynikach zapytania';
$strQuerySQLHistory = 'Historia SQL';
$strQueryStatistics = '<b>Statystyki zapyta</b>: Od rozpoczcia jego pracy, do serwera zostao wysanych %s zapyta.';
$strQueryTime = 'Wykonanie zapytania trwao %01.4f sekund(y)';
$strQueryType = 'Rodzaj zapytania';
$strQueryWindowLock = 'Nie nadpisuj tego zapytania spoza okna';

$strReadRequests = 'da odczytu';
$strReceived = 'Otrzymane';
$strRecords = 'Rekordy';
$strReferentialIntegrity = 'Sprawd spjno powiza:';
$strRefresh = 'Odwie';
$strRelationalSchema = 'Schemat relacyjny';
$strRelationNotWorking = 'Dodatkowe moliwoci pracy z poczonymi tabelami zostay wyczone. Aby dowiedzie si, dlaczego - kliknij %stutaj%s.';
$strRelationsForTable = 'RELACJE TABELI';
$strRelations = 'Relacje';
$strRelationView = 'Widok relacyjny';
$strReloadingThePrivileges = 'Przeaduj uprawnienia';
$strReloadPrivileges = 'Przeaduj uprawnienia';
$strRemoveSelectedUsers = 'Usu zaznaczonych uytkownikw';
$strRenameDatabaseOK = 'Baza danych %s ma nazw zmienion na %s';
$strRenameTableOK = 'Tabela %s ma nazw zmienion na %s';
$strRenameTable = 'Zmie nazw tabeli na';
$strRepairTable = 'Napraw tabel';
$strReplaceNULLBy = 'Zamiana NULL na';
$strReplaceTable = 'Zamiana danych tabeli z plikiem';
$strReplication = 'Replikacja';
$strReset = 'Reset';
$strResourceLimits = 'Ograniczenia zasobw';
$strReType = 'Ponownie';
$strRevokeAndDelete = 'Cofnij wszystkie aktywne uprawnienia uytkownikom, a nastpnie usu ich.';
$strRevokeAndDeleteDescr = 'Nim uprawnienia zostan przeadowane, uytkownicy nadal bd mieli uprawnienie USAGE.';
$strRevoke = 'Cofnij';
$strRevokeMessage = 'Uprawnienia dla %s zostay cofnite';
$strRomanian = 'Rumuski';
$strRowLength = 'Dugo rekordu';
$strRowsFrom = 'rekordw poczwszy od';
$strRowSize = ' Rozmiar rekordu ';
$strRowsModeFlippedHorizontal = 'poziomo (obrcone nagwki)';
$strRowsModeHorizontal = 'poziomo';
$strRowsModeOptions = 'w trybie %s powtrz nagwki po %s komrkach';
$strRowsModeVertical = 'pionowo';
$strRows = 'Rekordw';
$strRowsStatistic = 'Statystyka rekordw';
$strRunning = 'uruchomiony na %s';
$strRunQuery = 'Wykonaj zapytania';
$strRunSQLQueryOnServer = 'Uruchom zapytanie/zapytania SQL na serwerze %s';
$strRunSQLQuery = 'Wykonanie zapytania/zapyta SQL do bazy danych %s';
$strRussian = 'Rosyjski';

$strSaveOnServer = 'Zapisz na serwerze w katalogu %s';
$strSave = 'Zachowaj';
$strScaleFactorSmall = 'Wspczynnik skali jest za may, by schemat zmieci si na jednej stronie';
$strSearchFormTitle = 'Szukaj w bazie danych';
$strSearchInTables = 'Wewntrz tabel(i):';
$strSearchNeedle = 'Szukane sowa lub wartoci (symbol wieloznaczny: "%"):';
$strSearchOption1 = 'przynajmniej jedno ze sw';
$strSearchOption2 = 'wszystkie sowa';
$strSearchOption3 = 'caa fraza';
$strSearchOption4 = 'wyraenie regularne';
$strSearchResultsFor = 'Szukaj w rezultatach dla "<i>%s</i>" %s:';
$strSearch = 'Szukaj';
$strSearchType = 'Znajd:';
$strSecretRequired = 'Plik konfiguracyjny wymaga teraz tajnej frazy kodujcej (blowfish_secret).';
$strSelectADb = 'Prosz wybra baz danych';
$strSelectAll = 'Zaznacz wszystkie';
$strSelectBinaryLog = 'Wybierz dziennik binarny do podgldu';
$strSelectFields = 'Wybr pl (co najmniej jedno):';
$strSelectNumRows = 'w zapytaniu';
$strSelectTables = 'Wybierz tabele';
$strSend = 'Zapisz jako plik';
$strSent = 'Wysane';
$strServerChoice = 'Wybr serwera';
$strServerNotResponding = 'Serwer nie odpowiada';
$strServer = 'Serwer';
$strServers = 'Serwery';
$strServerStatusDelayedInserts = 'Opnione dodania';
$strServerStatus = 'Informacje o dziaaniu serwera';
$strServerStatusUptime = 'Serwer MySQL dziaa przez %s. Pocztek pracy: %s.';
$strServerTabVariables = 'Zmienne';
$strServerTrafficNotes = '<b>Ruch na serwerze</b>: Ponisze tabele pokazuj statystyki ruchu na tym serwerze MySQL od rozpoczcia jego pracy.';
$strServerVars = 'Zmienne i ustawienia serwera';
$strServerVersion = 'Wersja serwera';
$strSessionValue = 'Warto sesji';
$strSetEnumVal = 'Jeeli pole jest typu "ENUM" lub "SET", wartoci wprowadza si w formacie: \'a\',\'b\',\'c\'...<br />Jeeli potrzeba wprowadzi odwrotny ukonik ("\") lub apostrof ("\'"), naley je poprzedzi odwrotnym ukonikiem (np.: \'\\\\xyz\' lub \'a\\\'b\').';
$strShowAll = 'Poka wszystko';
$strShowColor = 'Poka kolor';
$strShowDatadictAs = 'Format sownika danych';
$strShowFullQueries = 'Poka pene zapytania';
$strShowGrid = 'Poka siatk';
$strShowingBookmark = 'Pokaz zapamitanego zapytania';
$strShowingRecords = 'Poka rekordy ';
$strShowOpenTables = 'Poka otwarte tabele';
$strShowPHPInfo = 'Informacje o PHP';
$strShow = 'Poka';
$strShowSlaveHosts = 'Poka podrzdne hosty';
$strShowSlaveStatus = 'Status serwera podrzdnego';
$strShowStatusBinlog_cache_disk_useDescr = 'Liczba transakcji, ktre uyway pamici podrcznej tymczasowego dziennika binarnego, ale ktry przekroczyy warto binlog_cache_size i do zapisania instrukcji transakcji zosta uyty plik tymczasowy.';
$strShowStatusBinlog_cache_useDescr = 'Liczba transakcji, ktre uyway pamici podrcznej tymczasowego dziennika binarnego.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Liczba tabel tymczasowych na dysku utworzonych automatycznie przez serwer podczas wykonywanie instrukcji. Przy duej wartoci Created_tmp_disk_tables, zwikszenie wartoci tmp_table_size spowoduje tworzenie tymczasowych tabel w pamici, a nie na dysku.';
$strShowStatusCreated_tmp_filesDescr = 'Ile plikw tymczasowych utworzy mysqld.';
$strShowStatusCreated_tmp_tablesDescr = 'Liczba tabel tymczasowych w pamici, utworzonych automatycznie przez serwer podczas wykonywania instrukcji.';
$strShowStatusDelayed_errorsDescr = 'Liczba rekordw zapisanych przy pomocy INSERT DELAYED, dla ktrych wystpi jaki bd (prawdopodobnie zdublowany klucz).';
$strShowStatusDelayed_insert_threadsDescr = 'Liczba uytych wtkw obsugujcych INSERT DELAYED. Kada osobna tabela, na ktrej wykonuje si INSERT DELAYED dostaje wasny wtek.';
$strShowStatusDelayed_writesDescr = 'Liczba rekordw zapisanych poprzez INSERT DELAYED.';
$strShowStatusFlush_commandsDescr  = 'Liczba wykonanych instrukcji FLUSH.';
$strShowStatusHandler_commitDescr = 'Liczba wewntrznych intrukcji COMMIT.';
$strShowStatusHandler_deleteDescr = 'Ile razy rekord zosta usunity z tabeli.';
$strShowStatusHandler_discoverDescr = 'Serwer MySQL moe zapyta mechanizm skadowania Cluster NDB, czy ma informacje o tabeli o zadanej nazwie. Nazywamy to odkryciem (<i>discovery</i>). Handler_discover wskazuje, ile razy tabela zostaa odkryta.';
$strShowStatusHandler_read_firstDescr = 'Ile razy z indeksu zostaa odczytana pierwsza pozycja. Dua warto sugeruje, e serwer wykonuje penych przeszuka indeksw; na przykad SELECT col1 FROM foo, przy zaoeniu, e col1 jest zindeksowane.';
$strShowStatusHandler_read_keyDescr = 'Liczba da odczytu rekordu na podstawie indeksu. Dua warto to dobra oznaka tego, e zapytania i tabele s waciwie zindeksowane.';
$strShowStatusHandler_read_nextDescr = 'Liczba da odczytu nastpnego rekordu w porzdku indeksowym. Ta warto jest zwikszana przy odpytywaniu o zindeksowan kolumn na ograniczonym przedziale lub przy przeszukiwaniu indeksu.';
$strShowStatusHandler_read_prevDescr = 'Liczba da odczytu poprzedniego rekordu w porzdku indeksowym. Metoda uywana gwnie do optymalizacji ORDER BY ... DESC.';
$strShowStatusHandler_read_rndDescr = 'Liczba da odczytu nastpnego rekordu na podstawie staego pooenia. Warto jest dua przy wykonywaniu duej iloci zapyta wymagajcych sortowania rezultatu. Prawdopodobnie wykonano wiele zapyta wymagajcych przeszukania caej tabeli lub zcze, ktre nie uywaj poprawnie indeksw.';
$strShowStatusHandler_read_rnd_nextDescr = 'Liczba da odczytu nastpnego rekord w pliku z danymi. Warto jest dua przy wykonywania wielu przeszukiwa tabeli. Oglnie sugeruje to, e tabele nie s poprawnie zindeksowane lub e zapytania nie s napisane w sposb pozwalajcy skorzysta z istniejcych indeksw.';
$strShowStatusHandler_rollbackDescr = 'Liczba wewntrznych instrukcji ROLLBACK.';
$strShowStatusHandler_updateDescr = 'Liczba da zmiany rekordu w tabeli.';
$strShowStatusHandler_writeDescr = 'Liczba da dodania rekordu do tabeli.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Liczba stron zawierajcych dane (brudnych lub czystych).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Liczba aktualnie brudnych stron.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Liczba stron w puli bufora, ktrych wymiecienia zadano.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Liczba wolnych stron.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Liczba stron zatrzanitych w puli bufora InnoDB. S to strony aktualnie odczytywane lub zapisywane lub takie, ktre nie mog zosta wymiecione lub usunite z jakiego innego powodu.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Liczba strony stron zajtych z powodu ich alokacji dla celw administracyjnych takich jak blokady rekordu lub adaptacyjny indeks haszujcy. Warto ta moe te zosta policzona jako Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'czny rozmiar puli bufora, w stronach.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'Liczba "losowych" odczytw z wyprzedzeniem zainicjowanych przez InnoDB. Wystpuje gdy zapytane przeszukiwaoby due fragmenty tabeli, ale w dowolnej kolejnoci.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'Liczba sekwencyjnych odczytw z wyprzedzeniem zainicjowanych przez InnoDB. Wystpuje gdy InnoDB wykonuje sekwencyjne pene przeszukiwanie tabeli.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'Liczba da logicznych odczytw ktre wykona InnoDB.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'Liczba logicznych odczytw, ktrych InnoDB nie mg zaspokoi pul bufora i musia wykona odczyt pojedynczej strony.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Zwykle zapis do puli bufora InnoDB obywa si w tle. Jednake, jeli niezbdny jest odczyt lub utworzenie strony a brak jest czystych stron, konieczne jest najpierw oczekiwanie na wymiecienie stron. Ten licznik wskazuje liczb wystpie takich oczekiwa. Jeeli rozmiar puli bufora by ustawiony waciwie, warto ta powinna by maa.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'Liczba wykonanych zapisw do puli bufora InnoDB.';
$strShowStatusInnodb_data_fsyncsDescr = 'Liczba dotd wykonanych operacji fsync().';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'Aktualna liczba operacji fsync() w toku.';
$strShowStatusInnodb_data_pending_readsDescr = 'Aktualna liczba odczytw w toku.';
$strShowStatusInnodb_data_pending_writesDescr = 'Aktualna liczba zapisw w toku.';
$strShowStatusInnodb_data_readDescr = 'Ilo dotd odczytanych danych, w bajtach.';
$strShowStatusInnodb_data_readsDescr = 'czna liczba odczytw danych.';
$strShowStatusInnodb_data_writesDescr = 'czna liczba zapisw danych.';
$strShowStatusInnodb_data_writtenDescr = 'Ilo dotd zapisanych danych, w bajtach.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Liczba przeprowadzonych zapisw typu <i>doublewrite</i>.';
$strShowStatusInnodb_dblwr_writesDescr = 'Liczba stron zapisanych przy zapisie typu <i>doublewrite</i>.';
$strShowStatusInnodb_log_waitsDescr = 'Ile razy czekano, bo bufor dziennika by zbyt may i przed wznowieniem pracy oczekiwano na jego oprnienie.';
$strShowStatusInnodb_log_write_requestsDescr = 'Liczba da zapisw do dziennika.';
$strShowStatusInnodb_log_writesDescr = 'Liczba fizycznych zapisw do pliku dziennika.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Liczba synchronicznych zapisw do pliku dziennika.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Liczba wywoa fsync dla pliku dziennika w toku.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Liczba zapisw do pliku dziennika w toku.';
$strShowStatusInnodb_os_log_writtenDescr = 'Liczba bajtw zapisanych do pliku dziennika.';
$strShowStatusInnodb_pages_createdDescr = 'Liczba utworzonych stron.';
$strShowStatusInnodb_page_sizeDescr = 'Wkompilowana wielko strony InnoDB (domylnie 16KB). Wiele wartoci jest mierzonych w stronach; znajomo wielkoci strony pozwala na ich atw konwersj na bajty.';
$strShowStatusInnodb_pages_readDescr = 'Liczba odczytanych stron.';
$strShowStatusInnodb_pages_writtenDescr = 'Liczba zapisanych stron.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'Liczba blokad rekordw na ktre aktualnie si czeka.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'redni czas uzyskania blokady rekordu, w milisekundach.';
$strShowStatusInnodb_row_lock_timeDescr = 'Cakowity czas zuyty na uzyskiwanie blokad rekordw, w milisekundach.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'Maksymalny czas uzyskania blokady rekordu, w milisekundach.';
$strShowStatusInnodb_row_lock_waitsDescr = 'Ile razy czekano na blokad rekordu.';
$strShowStatusInnodb_rows_deletedDescr = 'Liczba rekordw usunitych z tabel InnoDB.';
$strShowStatusInnodb_rows_insertedDescr = 'Liczba rekordw dodanych do tabel InnoDB.';
$strShowStatusInnodb_rows_readDescr = 'Liczba rekordw odczytanych z tabel InnoDB.';
$strShowStatusInnodb_rows_updatedDescr = 'Liczba rekordw zmienionych w tabelach InnoDB.';
$strShowStatusKey_blocks_not_flushedDescr = 'Liczba blokw w buforze podrcznym indeksw, ktre zostay zmodyfikowane ale jeszcze nie wymiecione na dysk. Wczeniej zmienna miaa nazw Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'Liczba nieuywanych blokw w buforze podrcznym indeksw. Mona uy tej wartoci do okrelenia jaka cz bufora indeksw jest w uyciu.';
$strShowStatusKey_blocks_usedDescr = 'Liczba uytych blokw w buforze podrcznym indeksw. Ta warto to prg, ktry wskazuje maksymaln liczb kiedykolwiek jednoczenie uytych blokw.';
$strShowStatusKey_read_requestsDescr = 'Liczba da odczytu bloku z bufora podrcznego indeksw.';
$strShowStatusKey_readsDescr = 'Liczba fizycznych odczytw blokw indeksw z dysku. Dua warto key_reads oznacza, e prawdopodobnie warto key_buffer_size jest zbyt maa. Wspczynnik chybie bufora podrcznego mona policzy ze wzoru Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'Liczba da zapisw blokw indeksw to bufora podrcznego.';
$strShowStatusKey_writesDescr = 'Liczba fizycznych zapisw blokw indeksw na dysk.';
$strShowStatusLast_query_costDescr = 'Cakowity koszta ostatnio skompilowanego zapytania, wyliczony przez optymalizator zapyta. Przydatny do porwna kosztw rnych planw wykonania tego samego zapytania. Domylna warto 0 oznacza, e jeszcze adne zapytanie nie zostao skompilowane.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Liczba rekordw oczekujcych na zapisanie w kolejkach INSERT DELAYED.';
$strShowStatusOpened_tablesDescr = 'Liczba kiedykolwiek otwartych tabel. Jeli ta warto jest dua, prawdopodobnie wielko pamici podrcznej tabel jest zbyt maa.';
$strShowStatusOpen_filesDescr = 'Liczba otwartych plikw.';
$strShowStatusOpen_streamsDescr = 'Liczba otwartych strumieni (uywanych gownie do rejestracji w dzienniku).';
$strShowStatusOpen_tablesDescr = 'Liczba otwartych tabel.';
$strShowStatusQcache_free_blocksDescr = 'Liczba wolnych blokw pamici w podrcznym buforze zapyta.';
$strShowStatusQcache_free_memoryDescr = 'Ilo dostpnej pamici w podrcznym buforze zapyta.';
$strShowStatusQcache_hitsDescr = 'Liczba trafie pamici podrcznej.';
$strShowStatusQcache_insertsDescr = 'Liczba zapyta dodanych do pamici podrcznej.';
$strShowStatusQcache_lowmem_prunesDescr = 'Liczba zapyta, ktre zostay usunite z pamici podrcznej, by zwolnic pami do buforowania nowych zapyta. Ta informacje moe pomc dostroi wielko bufora podrcznego. Do decydowania o tym, ktre zapytania usun z bufora podrcznego uywana jest strategia "najpierw najduej nieuywany" (<i>least recently used</i> - LRU).';
$strShowStatusQcache_not_cachedDescr = 'Liczba niezbuforowanych zapyta (nie dajcych si zbuforowa lub niezbuforowanych z powodu ustawienia query_cache_type).';
$strShowStatusQcache_queries_in_cacheDescr = 'Liczba zapyta zarejestrowanych w buforze podrcznym.';
$strShowStatusQcache_total_blocksDescr = 'Cakowita liczba blokw w buforze podrcznym zapyta.';
$strShowStatusReset = 'Zresetuj';
$strShowStatusRpl_statusDescr = 'Stan replikacji zabezpieczajcej (jeszcze nie zaimplementowane).';
$strShowStatusSelect_full_joinDescr = 'Liczba zcze nie uywajcych indeksw. Warto rna od 0 sugeruje staranne przyjrzenie si indeksom tabel.';
$strShowStatusSelect_full_range_joinDescr = 'Liczba zcze w ktrych uyto wyszukiwania zakresowego na pierwszej zczanej tabeli.';
$strShowStatusSelect_range_checkDescr = 'Liczba zcze bez uycia indeksw gdy moliwo ich uycia bya sprawdzana dla kadego rekordu. (Warto rna od 0 sugeruje staranne przyjrzenie si indeksom tabel.)';
$strShowStatusSelect_rangeDescr = 'Liczba zcze w ktrych uyto zakresw w stosunku do pierwszej tabeli. (Nawet dua warto nie ma kluczowego znaczenia.)';
$strShowStatusSelect_scanDescr = 'Liczba zcze, ktre przeszukay w peni pierwsz tabel.';
$strShowStatusSlave_open_temp_tablesDescr = 'Liczba tymczasowych tabel aktualnie otwartych przez podrzdny wtek SQL.';
$strShowStatusSlave_retried_transactionsDescr = 'Ile raz cznie (od startu) podrzdny wtek SQL replikacji ponawia transakcje.';
$strShowStatusSlave_runningDescr = 'ON oznacza, e ten serwer jest podrzdny i jest podczony go serwera gwnego.';
$strShowStatusSlow_launch_threadsDescr = 'Liczba wtkw, ktrych utworzenie trwao duej ni slow_launch_time sekund.';
$strShowStatusSlow_queriesDescr = 'Liczba zapyta, ktrych wykonanie zajo wicej ni long_query_time sekund.';
$strShowStatusSort_merge_passesDescr = 'Liczba przebiegw scalania, ktre musia wykona algorytm sortujcy. Przy duej wartoci, warto wzi pod uwag zwikszenie wartoci zmiennej systemowej sort_buffer_size.';
$strShowStatusSort_rangeDescr = 'Liczba sortowa wykonanych przy uyciu zakresw.';
$strShowStatusSort_rowsDescr = 'Liczba posortowanych rekordw.';
$strShowStatusSort_scanDescr = 'Liczba sortowa wykonanych poprzez przeszukiwanie tabeli.';
$strShowStatusTable_locks_immediateDescr = 'Ile razy blokada tabeli zostaa uzyskana natychmiastowo.';
$strShowStatusTable_locks_waitedDescr = 'Ile razy blokada tabeli nie moga zosta uzyskana natychmiastowo i niezbdne byo oczekiwanie. Przy wysoka warto oraz problemach z wydajnoci powinno si najpierw zoptymalizowa zapytania, a nastpnie podzieli tabel (tabele) lub uy replikacji.';
$strShowStatusThreads_cachedDescr = 'Liczba wtkw w buforze podrcznym wtkw. Wspczynnik trafienia w bufor moe by wyliczony ze wzoru Threads_created/Connections. Kolor czerwony oznacza, e powinno si zwikszy thread_cache_size.';
$strShowStatusThreads_connectedDescr = 'Liczba aktualnie otwartych pocze.';
$strShowStatusThreads_createdDescr = 'Liczba wtkw utworzonych by obsuy poczenia. Jeeli warto Threads_created jest dua, mona chcie zwikszy warto thread_cache_size. (W przypadku dobrej implementacja wtkw zwykle nie daje to zauwaalnego polepszenia wydajnoci.)';
$strShowStatusThreads_runningDescr = 'Liczba nieupionych wtkw.';
$strShowTableDimension = 'Poka wymiary tabel';
$strShowTables = 'Poka tabele';
$strShowThisQuery = ' Wywoaj ponownie zapytanie ';
$strSimplifiedChinese = 'Chiski uproszczony';
$strSingly = '(pojedynczo)';
$strSize = 'Rozmiar';
$strSkipQueries = 'Liczba rekordw (zapyta), ktre naley z pocztku pomin';
$strSlovak = 'Sowacki';
$strSlovenian = 'Soweski';
$strSocketProblem = '(lub gniazdo lokalnego serwera MySQL nie jest skonfigurowane poprawnie)';
$strSortByKey = 'Sortuj wg klucza';
$strSorting = 'Sortowanie';
$strSort = 'Sortuj';
$strSpaceUsage = 'Wykorzystanie przestrzeni';
$strSpanish = 'Hiszpaski';
$strSplitWordsWithSpace = 'Sowa s rozdzielane znakiem spacji (" ").';
$strSQLCompatibility = 'Tryb zgodnoci SQL';
$strSQLExportType = 'Rodzaj eksportu';
$strSQLParserBugMessage = 'Istnieje szansa, e wanie znaleziono bd w analizatorze skadni SQL. Prosz zbada bliej swoje zapytanie i sprawdzi, czy cudzysowy s poprawne i dobrze sparowane. Inn moliw przyczyn niepowodzenia moe by wysyanie pliku ze znakami binarnymi poza obszarem tekstu ujtego w cudzysowy. Mona rwnie sprawdzi zapytanie SQL poprzez lini polece MySQL-a. W znalezieniu przyczyny problemu moe pomc take - jeli si pojawi - poniszy opis bdu serwera MySQL. Jeli nadal wystpuj z problemy lub analizator skadni zgasza usterk a linia polece - nie, ogranicz sekwencj zapyta SQL do pojedynczego, ktre powoduje problemy i zgo bd, doczajc fragment danych zawarty w poniszej sekcji TNIJ:';
$strSQLParserUserError = 'Wyglda na to, e w twoim zapytaniu SQL jest bd. W znalezieniu przyczyny problemu moe pomc take - jeli si pojawi - poniszy opis bdu serwera MySQL.';
$strSQLQuery = 'zapytanie SQL';
$strSQLResult = 'Rezultat SQL';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Nieprawidowy identyfikator';
$strSQPBugUnclosedQuote = 'Niezamknity cudzysw';
$strSQPBugUnknownPunctuation = 'Nieznany znak przestankowy';
$strStatCheckTime = 'Ostatnie sprawdzenie';
$strStatCreateTime = 'Utworzenie';
$strStatement = 'Cecha';
$strStatisticsOverrun = 'Na aktywnym serwerze liczniki bajtw mog si przekrci, wic statystyki jakich dostarcza serwer MySQL nie s wiarygodne.';
$strStatUpdateTime = 'Ostatnia aktualizacja';
$strStatus = 'Status';
$strStorageEngine = 'Mechanizm skadowania';
$strStorageEngines = 'Mechanizmy skadowania';
$strStrucCSV = 'Dane CSV';
$strStrucData = 'Struktura i dane';
$strStrucExcelCSV = 'CSV dla MS Excel';
$strStrucNativeExcel = 'Dane w formacie macierzystym MS Excela';
$strStrucOnly = 'Tylko struktura';
$strStructPropose = 'Analiza zawartoci';
$strStructure = 'Struktura';
$strSubmit = 'Wylij';
$strSuccess = 'Zapytanie SQL zostao wykonane pomylnie';
$strSum = 'Suma';
$strSwedish = 'Szwedzki';
$strSwitchToDatabase = 'Przecz do skopiowanej bazy danych';
$strSwitchToTable = 'Przecz na skopiowan tabel';

$strTableAlreadyExists = 'Tabela %s ju istnieje!';
$strTableComments = 'Komentarze tabeli';
$strTableEmpty = 'Brak nazwy tabeli!';
$strTableHasBeenDropped = 'Tabela %s zostaa usunita';
$strTableHasBeenEmptied = 'Tabela %s zostaa oprniona';
$strTableHasBeenFlushed = 'Tabela %s zostaa przeadowana';
$strTableMaintenance = 'Zarzdzanie tabel';
$strTableOfContents = 'Spis treci';
$strTableOptions = 'Opcje tabeli';
$strTables = '%s tabel(a)';
$strTableStructure = 'Struktura tabeli dla ';
$strTable = 'Tabela';
$strTakeIt = 'uyj';
$strTblPrivileges = 'Uprawnienia specyficzne dla tabel';
$strTempData = 'Dane tymczasowe';
$strTextAreaLength = ' To pole moe nie da si edytowa<br /> z powodu swojej dugoci ';
$strThai = 'Tajski';
$strThemeDefaultNotFound = 'Nie znaleziono domylnego motywu graficznego %s!';
$strTheme = 'Motyw graficzny / styl';
$strThemeNoPreviewAvailable = 'Podgld niedostpny.';
$strThemeNotFound = 'Nie znaleziono motywu graficznego %s!';
$strThemeNoValidImgPath = 'Nie znaleziono prawidowej cieki do obrazka dla motywu graficznego %s!';
$strThemePathNotFound = 'Nie znaleziono cieki do motywu %s!';
$strThisHost = 'Ten host';
$strThreadSuccessfullyKilled = 'Wtek %s zosta pomylnie unicestwiony.';
$strThreads = 'Wtki';
$strTime = 'Czas';
$strTimeoutInfo = 'Poprzedni import przekroczy limit czasu, ponowne przedoenie tego pliku  spowoduje kontynuacje od miejsca %d.';
$strTimeoutNothingParsed = 'Jednake, podczas ostatniego uruchomienia nie zostay przetworzone adne dane, co zwykle oznacza, e phpMyAdmin nie bdzie w stanie ukoczy tego importu bez zwikszenia limitw czasowych PHP.';
$strTimeoutPassed = 'Limit czasu wykonania skryptu min; aby ukoczy import, prosz przedoy ten sam plik a import zostanie wznowiony.';
$strToggleScratchboard = 'wcz / wycz scratchboard';
$strTotalUC = 'Sumarycznie';
$strTotal = 'wszystkich';
$strTraditionalChinese = 'Chiski tradycyjny';
$strTraditionalSpanish = 'Tradycyjny hiszpaski';
$strTraffic = 'Ruch';
$strTransactionCoordinator = 'Koordynator transakcji';
$strTransformation_application_octetstream__download = 'Wywietla link do cignicia binarnych danych z tego pola. Pierwsza opcja to nazwa pliku binarnego. Drug opcj jest moliwa nazwa pola zawierajcego nazw pliku. Jeeli dana jest druga opcja, pierwsza musi by pustym napisem';
$strTransformation_application_octetstream__hex = 'Wywietla szesnastkow reprezentacj danych. Opcjonalny pierwszy parametr okrela jak czsto dodawane bd spacje (domylnie: co 2 pbajty).';
$strTransformation_image_jpeg__inline = 'Wywietla klikaln miniaturk; opcje: szeroko,wysoko w pikselach (oryginalne proporcje zostan zachowane)';
$strTransformation_image_jpeg__link = 'Wywietla link do tego obrazu (bezporednie cignicie bloba).';
$strTransformation_image_png__inline = 'Zobacz image/jpeg: inline';
$strTransformation_text_plain__external = 'TYLKO LINUX: Uruchamia zewntrzn aplikacj i przekazuje dane pl na standardowe wejcie. Zwraca standardowe wyjcie tej aplikacji. Domylnie jest to Tidy, ktrzy porzdkuje kod HTML. Ze wzgldu na bezpieczestwo, naley rcznie zmodyfikowa plik libraries/transformations/text_plain__external.inc.php i doda narzdzie, na ktrego uruchamianie pozwalasz. Pierwsz opcj jest liczba programw, ktrych chcesz uy, a drug s parametry programu. Jeeli trzeci parametr jest ustawiony na 1, zostanie dokonana konwersja wyjcia poprzez uycie htmlspecialchars() (Domyln wartoci jest 1). Jeeli czwarty parametr zosta ustawiony na 1, zawarto komrki nie bdzie zawijana, tak e cae wyjcie zostanie pokazane bez zmian formatu (domyln wartoci jest 1)';
$strTransformation_text_plain__formatted = 'Zachowuje oryginalne formatowanie pola. Neutralizowanie znakw niespecjalnych nie jest dokonywane.';
$strTransformation_text_plain__imagelink = 'Wywietla obrazek i link, pole zawiera nazw pliku; pierwsz opcj jest prefiks, taki jak "http://domena.com/", drug opcj jest szeroko w pikselach, trzeci opcj jest wysoko.';
$strTransformation_text_plain__link = 'Wywietla link, pole zawiera nazw pliku; pierwsza opcja to prefiks, taki jak "http://domena.com/", druga opcja to tytu linku.';
$strTransformation_text_plain__sql = 'Formatuj tekst traktujc jako zapytanie SQL z podwietlaniem skadni.';
$strTransformation_text_plain__substr = 'Pokazuje jedynie cz napisu. Pierwsza opcja to offset, od ktrego ma zacz si wywietlanie tekstu (domylnie 0). Druga opcja to ilo zwracanego tekstu. Jeeli jest pusta, zwracany jest cay pozostay tekst. Trzecia opcja okrela jakie znaki zostan dodane do wyjcia, jeeli zwracany jest cz napisu (domylnie: ...) .';
$strTruncateQueries = 'Ucinaj wywietlane zapytania';
$strTurkish = 'Turecki';
$strType = 'Typ';

$strUkrainian = 'Ukraiski';
$strUncheckAll = 'Odznacz wszystkie';
$strUnicode = 'Unikod';
$strUnique = 'Jednoznaczny';
$strUnknown = 'nieznany';
$strUnselectAll = 'Odznacz wszystkie';
$strUnsupportedCompressionDetected = 'Prbowano wczyta plik z nieobsugiwanym typem kompresji (%s). Albo jego obsuga nie zostaa zaimplementowana albo zostaa konfiguracyjnie wyczona.';
$strUpdatePrivMessage = 'Uaktualnie uprawnienia dla %s.';
$strUpdateProfileMessage = 'Profil zosta uaktualniony.';
$strUpdateQuery = 'Zmie zapytanie';
$strUpdComTab = 'Informacje o tym, jak zaktualizowa tabel Column_comments znajduj si w dokumentacji';
$strUpgrade = 'Poleca si aktualizacj do %s w wersji %s lub pniejszej.';
$strUploadLimit = 'Prawdopodobnie prbowano wrzuci duy plik. Aby pozna sposoby obejcia tego limitu, prosz zapozna si z %sdokumenacj%s.';
$strUploadsNotAllowed = 'Serwer nie pozwala na upload plikw.';
$strUsage = 'Wykorzystanie';
$strUseBackquotes = 'Uyj cudzysoww z nazwami tabel i pl';
$strUsedPhpExtensions = 'Uywane rozszerzenia PHP';
$strUseHostTable = 'Uyj tabeli hostw';
$strUserAlreadyExists = 'Uytkownik %s ju istnieje!';
$strUserEmpty = 'Brak nazwy uytkownika!';
$strUserName = 'Nazwa uytkownika';
$strUserNotFound = 'Wybrany uytkownik nie zosta znaleziony w tabeli uprawnie.';
$strUserOverview = 'Opis uytkownika';
$strUsersDeleted = 'Wybrani uytkownicy zostali pomylnie usunici.';
$strUsersHavingAccessToDb = 'Uytkownicy majcy dostp do &quot;%s&quot;';
$strUser = 'Uytkownik';
$strUseTabKey = 'Klawisz TAB przemieszcza pomidzy wartociami, CTRL+strzaka przenosi w dowolne miejsce';
$strUseTables = 'Uyj tabel';
$strUseTextField = 'Uyj pola tekstowego';
$strUseThisValue = 'Uyj tej wartoci';

$strValidateSQL = 'Sprawd poprawno SQL';
$strValidatorError = 'Analizator skadni SQL nie mg zosta zainicjowany. Sprawd, czy zainstalowane s niezbdne rozszerzenia PHP, tak jak zostao to opisane w %sdokumentacji%s.';
$strValue = 'Warto';
$strVar = 'Zmienna';
$strVersionInformation = 'Informacja o wersji';
$strViewDumpDatabases = 'Zrzut baz danych';
$strViewDumpDB = 'Zrzut bazy danych';
$strViewDump = 'Zrzut tabeli';
$strViewHasBeenDropped = 'Perspektywa %s zostaa usunita';
$strViewMaxExactCount = 'Perspektywa ma ponad %d rekordw. Prosz zajrze do %sdokumentacji%s.';
$strView = 'Perspektywa';

$strWebServerUploadDirectoryError = 'Katalog ustalony dla uploadu jest nieosigalny';
$strWebServerUploadDirectory = 'katalog serwera WWW dla uploadu';
$strWelcome = 'Witamy w %s';
$strWestEuropean = 'Zachodnioeuropejski';
$strWildcard = 'znak wieloznaczny';
$strWindowNotFound = 'Docelowe okno przegldarki nie mogo by zaktualizowane. By moe okno-rodzic zostao zamknite lub przegldarka, uwzgldniajc ustawienia bezpieczestwa, blokuje aktualizacje pomidzy oknami';
$strWithChecked = 'Zaznaczone:';
$strWriteRequests = 'da zapisu';
$strWrongUser = 'Bdne pola uytkownik/haso. Brak dostpu.';

$strXML = 'XML';

$strYes = 'Tak';

$strZeroRemovesTheLimit = 'Uwaga: Ustawienie tych opcji na 0 (zero) usuwa ograniczenie.';
$strZip = '".zip"';

$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
$strViewName = 'VIEW name';  //to translate
$strOptions = 'Options';  //to translate
$strFiles = 'Files';  //to translate
$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
$strRoutines = 'Routines';  //to translate
$strRoutineReturnType = 'Return type';  //to translate
$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
$strTriggers = 'Triggers';  //to translate
$strEvent = 'Event';  //to translate
$strProfiling = 'Profiling';  //to translate
?>
